@@ -44,11 +44,12 @@ sub post : Local {
 
     my $reply_to = 0;
     if ( $object_type eq 'topic' ) {
-        my $topic
-            = $c->controller('Get')->topic( $c, $object_id, { forum_id => $forum_id } );
+        my $topic = $c->controller('Get')
+            ->topic( $c, $object_id, { forum_id => $forum_id } );
 
         # topic is closed or not
-        $c->detach( '/print_error', ['ERROR_CLOSED'] ) if ( $topic->{closed} );
+        $c->detach( '/print_error', ['ERROR_CLOSED'] )
+            if ( $topic->{closed} );
 
         # for topic. only the first comment (topic) is reply_to == 0.
         # get the first comment for reply_to
@@ -61,7 +62,8 @@ sub post : Local {
                 page     => 1,
                 columns  => ['comment_id'],
             }
-        );    # I'm confused that why search->first is not working at all. YYY?
+            )
+            ; # I'm confused that why search->first is not working at all. YYY?
               # and why find is working at all
         $c->detach( '/print_error', ['ERROR_CLOSED'] ) unless ($rs);
         $reply_to = $rs->comment_id;
@@ -121,9 +123,6 @@ sub post : Local {
         );
     }
 
-    # update user stat
-    $c->model('DBIC::User')->update_user( $c->user, { replies => \"replies + 1" } );    #"
-
     if ($forum_id) {
         $c->forward( '/clear_when_topic_changes', [$forum] );
     }
@@ -148,8 +147,10 @@ sub reply : LocalRegex('^(\d+)/reply$') {
     my $comment    = $c->model('Get')
         ->comment( $c, $comment_id, { with_author => 1, with_text => 1 } );
 
-    my ( $object_id, $object_type, $forum_id )
-        = ( $comment->{object_id}, $comment->{object_type}, $comment->{forum_id} );
+    my ( $object_id, $object_type, $forum_id ) = (
+        $comment->{object_id}, $comment->{object_type},
+        $comment->{forum_id}
+    );
 
     my $forum;
     $forum = $c->controller('Get')->forum( $c, $forum_id ) if ($forum_id);
@@ -160,11 +161,12 @@ sub reply : LocalRegex('^(\d+)/reply$') {
         }
     }
     if ( $object_type eq 'topic' ) {
-        my $topic
-            = $c->controller('Get')->topic( $c, $object_id, { forum_id => $forum_id } );
+        my $topic = $c->controller('Get')
+            ->topic( $c, $object_id, { forum_id => $forum_id } );
 
         # topic is closed or not
-        $c->detach( '/print_error', ['ERROR_CLOSED'] ) if ( $topic->{closed} );
+        $c->detach( '/print_error', ['ERROR_CLOSED'] )
+            if ( $topic->{closed} );
     }
 
     return unless ( $c->req->method eq 'POST' );
@@ -175,10 +177,12 @@ sub reply : LocalRegex('^(\d+)/reply$') {
     my $upload    = $c->req->upload('upload');
     my $upload_id = 0;
     if ($upload) {
-        $upload_id
-            = $c->model('DBIC::Upload')
-            ->add_file( $upload,
-            { forum_id => $comment->{forum_id}, user_id => $c->user->user_id } );
+        $upload_id = $c->model('DBIC::Upload')->add_file(
+            $upload,
+            {   forum_id => $comment->{forum_id},
+                user_id  => $c->user->user_id
+            }
+        );
         unless ( $upload_id =~ /^\d+$/ ) {
             return $c->set_invalid_form( upload => $upload_id );
         }
@@ -230,9 +234,6 @@ sub reply : LocalRegex('^(\d+)/reply$') {
         );
     }
 
-    # update user stat
-    $c->model('DBIC::User')->update_user( $c->user, { replies => \"replies + 1" } );    #"
-
     if ($forum_id) {
         $c->forward( '/clear_when_topic_changes', [$forum] );
     }
@@ -272,8 +273,8 @@ sub edit : LocalRegex('^(\d+)/edit$') {
     # edit upload
     my $old_upload;
     if ( $comment->{upload_id} ) {
-        $old_upload
-            = $c->model('DBIC::Upload')->find( { upload_id => $comment->{upload_id} } );
+        $old_upload = $c->model('DBIC::Upload')
+            ->find( { upload_id => $comment->{upload_id} } );
     }
     $c->stash->{upload} = $old_upload;
 
@@ -284,7 +285,8 @@ sub edit : LocalRegex('^(\d+)/edit$') {
 
     my $new_upload = $c->req->upload('upload');
     my $upload_id  = $comment->{upload_id};
-    if ( ( $c->req->param('attachment_action') eq 'delete' ) or $new_upload ) {
+    if ( ( $c->req->param('attachment_action') eq 'delete' ) or $new_upload )
+    {
 
         # delete old upload
         if ($old_upload) {
@@ -294,10 +296,12 @@ sub edit : LocalRegex('^(\d+)/edit$') {
 
         # add new upload
         if ($new_upload) {
-            $upload_id
-                = $c->model('DBIC::Upload')
-                ->add_file( $new_upload,
-                { forum_id => $comment->{forum_id}, user_id => $c->user->user_id } );
+            $upload_id = $c->model('DBIC::Upload')->add_file(
+                $new_upload,
+                {   forum_id => $comment->{forum_id},
+                    user_id  => $c->user->user_id
+                }
+            );
             unless ( $upload_id =~ /^\d+$/ ) {
                 return $c->set_invalid_form( upload => $upload_id );
             }
@@ -310,8 +314,8 @@ sub edit : LocalRegex('^(\d+)/edit$') {
 
     $title = encodeHTML($title);
 
-    $c->model('DBIC')->resultset('Comment')->search( { comment_id => $comment_id, } )
-        ->update(
+    $c->model('DBIC')->resultset('Comment')
+        ->search( { comment_id => $comment_id, } )->update(
         {   title     => $title,
             text      => $text,
             formatter => $formatter,
@@ -321,8 +325,10 @@ sub edit : LocalRegex('^(\d+)/edit$') {
         }
         );
 
-    my ( $object_id, $object_type, $forum_id )
-        = ( $comment->{object_id}, $comment->{object_type}, $comment->{forum_id} );
+    my ( $object_id, $object_type, $forum_id ) = (
+        $comment->{object_id}, $comment->{object_type},
+        $comment->{forum_id}
+    );
     my $info = {
         object_type => $object_type,
         object_id   => $object_id,
@@ -332,7 +338,8 @@ sub edit : LocalRegex('^(\d+)/edit$') {
 
     # for topic
     if ( $object_type eq 'topic' and $comment->{reply_to} == 0 ) {
-        $c->model('DBIC')->resultset('Topic')->search( { topic_id => $object_id } )
+        $c->model('DBIC')->resultset('Topic')
+            ->search( { topic_id => $object_id } )
             ->update( { title => $title } );
     }
 
@@ -357,8 +364,10 @@ sub delete : LocalRegex('^(\d+)/delete$') {
     my $comment_id = $c->req->snippets->[0];
     my $comment = $c->model('Get')->comment( $c, $comment_id );
 
-    my ( $object_id, $object_type, $forum_id )
-        = ( $comment->{object_id}, $comment->{object_type}, $comment->{forum_id} );
+    my ( $object_id, $object_type, $forum_id ) = (
+        $comment->{object_id}, $comment->{object_type},
+        $comment->{forum_id}
+    );
 
     my $forum;
     $forum = $c->controller('Get')->forum( $c, $forum_id ) if ($forum_id);
@@ -385,20 +394,22 @@ sub delete : LocalRegex('^(\d+)/delete$') {
 
     # esp treat
     if ( $object_type eq 'topic' ) {
-        my $topic
-            = $c->controller('Get')->topic( $c, $object_id, { forum_id => $forum_id } );
+        my $topic = $c->controller('Get')
+            ->topic( $c, $object_id, { forum_id => $forum_id } );
         if ( $comment->{reply_to} == 0 ) {
 
             # u can only delete 5 topics one day
-            my $most_deletion_per_day = $c->config->{per_day}->{most_deletion_topic}
+            my $most_deletion_per_day
+                = $c->config->{per_day}->{most_deletion_topic}
                 || 5;
-            my $one_day_ago   = time() - 86400;
-            my $deleted_count = $c->model('DBIC')->resultset('LogAction')->count(
+            my $one_day_ago = time() - 86400;
+            my $deleted_count
+                = $c->model('DBIC')->resultset('LogAction')->count(
                 {   forum_id => $forum_id,
                     action   => 'delete',
                     time     => { '>', $one_day_ago }
                 }
-            );
+                );
             if ( $deleted_count >= $most_deletion_per_day ) {
                 $c->detach(
                     '/print_error',
@@ -407,9 +418,12 @@ sub delete : LocalRegex('^(\d+)/delete$') {
                 );
             }
 
-            $c->model('DBIC::Topic')
-                ->remove( $forum_id, $object_id,
-                { log_text => $comment->{title}, operator_id => $c->user->user_id } );
+            $c->model('DBIC::Topic')->remove(
+                $object_id,
+                {   log_text    => $comment->{title},
+                    operator_id => $c->user->user_id
+                }
+            );
             $path = $forum->{forum_url};
             $c->forward( '/clear_when_topic_changes', [$forum] );
         }
@@ -418,7 +432,8 @@ sub delete : LocalRegex('^(\d+)/delete$') {
     # delete comment
     my $delete_counts = 0;
     unless ( $object_type eq 'topic' and $comment->{reply_to} == 0 ) {
-        $delete_counts = $c->model('DBIC::Comment')->remove_children($comment);
+        $delete_counts
+            = $c->model('DBIC::Comment')->remove_children($comment);
     }
 
     if ( $object_type eq 'topic' and $comment->{reply_to} != 0 ) {
