@@ -20,7 +20,8 @@ sub schema {
 
     $schema
         = Foorum::Schema->connect( $config->{dsn}, $config->{dsn_user},
-        $config->{dsn_pwd}, { AutoCommit => 1, RaiseError => 1, PrintError => 1 },
+        $config->{dsn_pwd},
+        { AutoCommit => 1, RaiseError => 1, PrintError => 1 },
         );
     return $schema;
 }
