@@ -17,7 +17,8 @@ sub work {
     my $schema = schema();
 
     # for /site/popular
-    my ( $sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst ) = localtime();
+    my ( $sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst )
+        = localtime();
 
     my $sql = 'UPDATE hit SET ';
     if ( $hour == 1 and $min < 5 ) {    # the first hour of today
@@ -32,7 +33,8 @@ sub work {
 
         $sql .= 'hit_weekly = hit_weekly + hit_new, ';
     }
-    if ( $mday == 1 and ( $hour == 1 and $min < 5 ) ) {    # The first day of the month
+    if ( $mday == 1 and ( $hour == 1 and $min < 5 ) )
+    {    # The first day of the month
         $sql .= 'hit_monthly = hit_new, ';
     } else {
 
@@ -44,17 +46,20 @@ sub work {
     $dbh->do($sql);
 
     # update the real data in table
-    my $rs = $schema->resultset('Hit')->search( { last_update_time => { '>', 0 } } );
+    my $rs = $schema->resultset('Hit')
+        ->search( { last_update_time => { '>', 0 } } );
     my $last_update_time = 0;
     my $updated_count    = 0;
     while ( my $r = $rs->next ) {
 
         # update into real table
         if ( $r->object_type eq 'topic' ) {
-            $schema->resultset('Topic')->search( { topic_id => $r->object_id } )
+            $schema->resultset('Topic')
+                ->search( { topic_id => $r->object_id } )
                 ->update( { hit => $r->hit_all, } );
         } elsif ( $r->object_type eq 'poll' ) {
-            $schema->resultset('Poll')->search( { poll_id => $r->object_id, } )
+            $schema->resultset('Poll')
+                ->search( { poll_id => $r->object_id, } )
                 ->update( { hit => $r->hit_all, } );
         }
         $last_update_time = $r->last_update_time
@@ -71,7 +76,8 @@ sub work {
         }
     )->update( { last_update_time => 0 } );
 
-    error_log( $schema, 'info', "update_hit ($updated_count) - $sql \@ " . localtime() );
+    error_log( $schema, 'info',
+        "update_hit ($updated_count) - $sql \@ " . localtime() );
 
     $job->completed();
 }
