@@ -20,12 +20,15 @@ $Email = HTML::Email::Obfuscate->new();
 __PACKAGE__->config(
 
     #DEBUG        => DEBUG_PARSER | DEBUG_PROVIDER,
-    INCLUDE_PATH =>
-        [ Foorum->path_to( 'templates', 'custom' ), Foorum->path_to('templates') ],
-    COMPILE_DIR => File::Spec->catdir( $tmpdir, 'ttcache', $< ),
-    COMPILE_EXT => '.ttp1',
-    STASH       => Template::Stash::XS->new,
-    FILTERS     => {
+    INCLUDE_PATH => [
+        Foorum->path_to( 'templates', 'custom' ),
+        Foorum->path_to('templates')
+    ],
+    TEMPLATE_EXTENSION => '.html',
+    COMPILE_DIR        => File::Spec->catdir( $tmpdir, 'ttcache', $< ),
+    COMPILE_EXT        => '.ttp1',
+    STASH              => Template::Stash::XS->new,
+    FILTERS            => {
         email_obfuscate => sub               { $Email->escape_html(shift) },
         decodeHTML      => sub               { decodeHTML(shift) },
         be_url_part     => sub               { be_url_part(shift) },
